============
Installation
============

This section explains how to install your local instance of Plone Intranet.
Pick the quickstart option if you want to try it out.
Pick the development option if you want to develop for Plone Intranet.


.. toctree::
    :maxdepth: 2

    quickstart
    development
    production
    ldap

